\name{predict.ams.pp.strap.model}
\alias{predict.ams.pp.strap.model}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ ~~function to do ... ~~ }
\description{
  ~~ A concise (1-5 lines) description of what the function does. ~~
}
\usage{
predict.ams.pp.strap.model(model, EFA = TRUE, data, bic.steps = 0, gdf = TRUE, includingZero = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{model}{ ~~Describe \code{model} here~~ }
  \item{EFA}{ ~~Describe \code{EFA} here~~ }
  \item{data}{ ~~Describe \code{data} here~~ }
  \item{bic.steps}{ ~~Describe \code{bic.steps} here~~ }
  \item{gdf}{ ~~Describe \code{gdf} here~~ }
  \item{includingZero}{ ~~Describe \code{includingZero} here~~ }
}
\details{
  ~~ If necessary, more details than the description above ~~
}
\value{
  ~Describe the value returned
  If it is a LIST, use
  \item{comp1 }{Description of 'comp1'}
  \item{comp2 }{Description of 'comp2'}
  ...
}
\references{ ~put references to the literature/web site here ~ }
\author{ ~~who you are~~ }
\note{ ~~further notes~~ 
}
\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\keyword{ multivariate }
