\name{ams.pp.internal}
\alias{ams.pp.bins2breaks}
\alias{ams.pp.boolean2range}
\alias{ams.pp.strap.lars}
\alias{nnls.fit}
\alias{peaks}
\alias{getDistributionHBin}
\alias{buildAveragineModelShort}
\alias{sulveragine}
\alias{findMaxPeakAndPositionUns}
\alias{exactAveragine}
\alias{joinAdjacent}
\alias{lightAveragine}
\alias{findMaxPeakAndPosition}
\alias{fftDiscrete}
\alias{xMoved}
\title{ ams.pp internal functions }
\description{
  Internal functions.
}
%\usage{
%ams.pp.bins2breaks(bins)
%}
%%- maybe also 'usage' for other objects documented here.
%\arguments{
%  \item{bins}{ ~~Describe \code{bins} here~~ }
%}
%\details{
%  ~~ If necessary, more details than the description above ~~
%}
%\value{
%  ~Describe the value returned
%  If it is a LIST, use
%  \item{comp1 }{Description of 'comp1'}
%  \item{comp2 }{Description of 'comp2'}
%  ...
%}
%\references{ ~put references to the literature/web site here ~ }
\author{Marc Kirchner \email{marc.kirchner@iwr.uni-heidelberg.de} }
\examples{}
\keyword{multivariate}
