\name{ams.pp.runSingleRegression}
\alias{ams.pp.runSingleRegression}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ ~~function to do ... ~~ }
\description{
  ~~ A concise (1-5 lines) description of what the function does. ~~
}
\usage{
ams.pp.runSingleRegression(data, bins, charges = c(2, 3, 4, 5), thresholdR2, width = 1e-04, sulLevels = 3, thresholdBetaHat = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{ ~~Describe \code{data} here~~ }
  \item{bins}{ ~~Describe \code{bins} here~~ }
  \item{charges}{ ~~Describe \code{charges} here~~ }
  \item{thresholdR2}{ ~~Describe \code{thresholdR2} here~~ }
  \item{width}{ ~~Describe \code{width} here~~ }
  \item{sulLevels}{ ~~Describe \code{sulLevels} here~~ }
  \item{thresholdBetaHat}{ ~~Describe \code{thresholdBetaHat} here~~ }
}
\details{
  ~~ If necessary, more details than the description above ~~
}
\value{
  ~Describe the value returned
  If it is a LIST, use
  \item{comp1 }{Description of 'comp1'}
  \item{comp2 }{Description of 'comp2'}
  ...
}
\references{ ~put references to the literature/web site here ~ }
\author{ ~~who you are~~ }
\note{ ~~further notes~~ 
}
\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\keyword{ multivariate }
