\name{ams.pp.buildModelMatrix}
\alias{ams.pp.buildModelMatrix}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ ~~function to do ... ~~ }
\description{
  ~~ A concise (1-5 lines) description of what the function does. ~~
}
\usage{
ams.pp.buildModelMatrix(begin, end, offset, data, EFA = TRUE, maxRangeSize = 1, thresholdInt = 0, limit = 1e-26, charge = c(2, 3, 4, 5), width = width)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{begin}{ ~~Describe \code{begin} here~~ }
  \item{end}{ ~~Describe \code{end} here~~ }
  \item{offset}{ ~~Describe \code{offset} here~~ }
  \item{data}{ ~~Describe \code{data} here~~ }
  \item{EFA}{ ~~Describe \code{EFA} here~~ }
  \item{maxRangeSize}{ ~~Describe \code{maxRangeSize} here~~ }
  \item{thresholdInt}{ ~~Describe \code{thresholdInt} here~~ }
  \item{limit}{ ~~Describe \code{limit} here~~ }
  \item{charge}{ ~~Describe \code{charge} here~~ }
  \item{width}{ ~~Describe \code{width} here~~ }
}
\details{
  ~~ If necessary, more details than the description above ~~
}
\value{
  ~Describe the value returned
  If it is a LIST, use
  \item{comp1 }{Description of 'comp1'}
  \item{comp2 }{Description of 'comp2'}
  ...
}
\references{ ~put references to the literature/web site here ~ }
\author{ ~~who you are~~ }
\note{ ~~further notes~~ 
}
\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\keyword{multivariate}
